@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2015 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -20,11 +20,14 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Grid Search Filters
 """
 
+from __future__ import unicode_literals
+
+import re
+
 from sqlalchemy import func, or_
 
 from webhelpers.html import tags
@@ -180,6 +183,23 @@ def filter_ilike(field):
     return {'lk': ilike, 'nl': not_ilike}
 
 
+def filter_int(field):
+    """
+    Returns a filter map entry for an integer field.  This provides exact
+    matching but also strips out non-numeric characters to avoid type errors.
+    """
+
+    def filter_is(q, v):
+        v = re.sub(r'\D', '', v or '')
+        return q.filter(field == int(v)) if v else q
+
+    def filter_nt(q, v):
+        v = re.sub(r'\D', '', v or '')
+        return q.filter(field != int(v)) if v else q
+
+    return {'is': filter_is, 'nt': filter_nt}
+
+
 def filter_soundex(field):
     """
     Returns a filter map entry which leverages the `soundex()` SQL function.
@@ -255,7 +275,7 @@ def get_filter_config(prefix, request, filter_map, **kwargs):
     return config
 
 
-def get_filter_map(cls, exact=[], ilike=[], **kwargs):
+def get_filter_map(cls, exact=[], ilike=[], int_=[], **kwargs):
     """
     Convenience function which returns a "filter map" for ``cls``.
 
@@ -265,6 +285,9 @@ def get_filter_map(cls, exact=[], ilike=[], **kwargs):
     ``ilike``, if provided, should be a list of field names for which "ILIKE"
     filtering is to be allowed.
 
+    ``int_``, if provided, should be a list of field names for which "integer"
+    filtering is to be allowed.
+
     Any remaining ``kwargs`` are assumed to be filter map entries themselves,
     and are added directly to the map.
     """
@@ -274,6 +297,8 @@ def get_filter_map(cls, exact=[], ilike=[], **kwargs):
         fmap[name] = filter_exact(getattr(cls, name))
     for name in ilike:
         fmap[name] = filter_ilike(getattr(cls, name))
+    for name in int_:
+        fmap[name] = filter_int(getattr(cls, name))
     fmap.update(kwargs)
     return fmap
 
@@ -294,17 +319,16 @@ def get_search_form(request, filter_map, config):
 
 def filter_query(query, config, filter_map, join_map):
     """
-    Filters ``query`` according to ``config`` and ``filter_map``.  ``join_map``
-    is used, if necessary, to join additional tables to the base query.  The
+    Filters the given query according to filter and sorting hints found within
+    the config dictionary, using the filter and join maps as needed.  The
     filtered query is returned.
     """
-
     joins = config.setdefault('joins', [])
     for key in config:
         if key.startswith('include_filter_') and config[key]:
             field = key[15:]
             value = config.get(field)
-            if value:
+            if value != '':
                 if field in join_map and field not in joins:
                     query = join_map[field](query)
                     joins.append(field)
