@@ -138,6 +138,9 @@ class SearchableAlchemyGridView(PagedAlchemyGridView):
     def filter_ilike(self, field):
         return grids.search.filter_ilike(field)
 
+    def filter_int(self, field):
+        return grids.search.filter_int(field)
+
     def filter_soundex(self, field):
         return grids.search.filter_soundex(field)
 
