@@ -158,7 +158,7 @@ class ProductsGrid(SearchableAlchemyGridView):
     def filter_config(self):
         return self.make_filter_config(
             include_filter_upc=True,
-            filter_type_upc='eq',
+            filter_type_upc='is',
             filter_label_upc="UPC",
             include_filter_brand=True,
             filter_type_brand='lk',
